@@ -91,6 +91,12 @@ public class RequestHandler {
     System.arraycopy(contact, 0, this.contact, 0, contact.length);
   }
 
+  private String version;
+
+  public void setVersion(String version) {
+    this.version = version;
+  }
+
   private String[] order;
 
   public void setOrder(String[] order) {
@@ -158,6 +164,7 @@ public class RequestHandler {
     this.filterNodesByLastSeenDays();
     this.filterByContact();
     this.filterByFamily();
+    this.filterByVersion();
     this.order();
     this.offset();
     this.limit();
@@ -261,7 +268,8 @@ public class RequestHandler {
       } else {
         List<String> addresses = entry.getAddresses();
         for (String address : addresses) {
-          if (address.startsWith(searchTerm.toLowerCase())) {
+          if (address.startsWith(searchTerm.toLowerCase())
+              || address.startsWith("[" + searchTerm.toLowerCase())) {
             /* Address matches. */
             lineMatches = true;
             break;
@@ -513,6 +521,22 @@ public class RequestHandler {
     this.filteredBridges.clear();
   }
 
+  private void filterByVersion() {
+    if (null == this.version) {
+      /* Not filtering by version. */
+      return;
+    }
+    Set<String> keepRelays = new HashSet<>();
+    for (Map.Entry<String, Set<String>> e
+        : this.nodeIndex.getRelaysByVersion().entrySet()) {
+      if (e.getKey().startsWith(this.version)) {
+        keepRelays.addAll(e.getValue());
+      }
+    }
+    this.filteredRelays.keySet().retainAll(keepRelays);
+    this.filteredBridges.clear();
+  }
+
   private void order() {
     List<SummaryDocument> uniqueRelays = new ArrayList<>();
     List<SummaryDocument> uniqueBridges = new ArrayList<>();
